@@ -20,8 +20,6 @@
 #define DIALOG_OVERWRITEFILE_H
 
 #include <gtkmm/messagedialog.h>
-#include <gtkmm/label.h>
-#include <gtkmm/box.h>
 
 namespace Bakery
 {
